@@ -3,7 +3,8 @@ from __future__ import annotations
 import datetime
 import decimal
 from types import TracebackType
-from typing import List, Tuple, Any, Dict, Sequence, Optional, Literal, Type
+from typing import List, Tuple, Any, Dict, Sequence, Optional, Type
+from typing_extensions import Literal
 
 import boto3
 
@@ -46,16 +47,17 @@ from meadowrun.run_job_core import AllocCloudInstancesInternal, JobCompletion, S
 # AMIs that have meadowrun pre-installed. These are all identical, we just need to
 # replicate into each region.
 _EC2_ALLOC_AMIS = {
-    "us-east-2": "ami-07653668da87ca748",
-    "us-east-1": "ami-023ef6195ecb8e648",
-    "us-west-1": "ami-032b1753347534924",
-    "us-west-2": "ami-074513d806ac4d30e",
-    "eu-central-1": "ami-068c10b14043c89d0",
-    "eu-west-1": "ami-0e5d382309d0a5906",
-    "eu-west-2": "ami-05dba868373463124",
-    "eu-west-3": "ami-0f8a2de09fa92ae08",
-    "eu-north-1": "ami-024bb642686e9e0ca",
+    "us-east-2": "ami-03ef5e2fa1ff3e8c7",
+    "us-east-1": "ami-07eb3f5f0d7528aa2",
+    "us-west-1": "ami-018a31e052d1e1a0e",
+    "us-west-2": "ami-07d4a3ab5f97408a1",
+    "eu-central-1": "ami-09d497a6c352622e4",
+    "eu-west-1": "ami-00eb14c6e74b73d0c",
+    "eu-west-2": "ami-00bcfdae29cd067d4",
+    "eu-west-3": "ami-0acc373d53927f8e3",
+    "eu-north-1": "ami-09e2ff4f607d2eb4e",
 }
+SSH_USER = "ubuntu"
 
 
 def ensure_ec2_alloc_table(region_name: str) -> None:
@@ -399,7 +401,7 @@ async def run_job_ec2_instance_registrar(
         )
 
     fabric_kwargs: Dict[str, Any] = {
-        "user": "ubuntu",
+        "user": SSH_USER,
         "connect_kwargs": {"pkey": pkey},
     }
 
