@@ -421,9 +421,13 @@ def _get_path_and_hash(
             spec_hash = hash_spec(environment_spec.spec_lock.encode("UTF-8"))
             path_to_spec = os.path.join(interpreter_spec_path, spec_hash)
             os.makedirs(path_to_spec, exist_ok=True)
-            with open(os.path.join(path_to_spec, "pyproject.toml"), "w", encoding="utf-8") as spec_file:
+            with open(
+                os.path.join(path_to_spec, "pyproject.toml"), "w", encoding="utf-8"
+            ) as spec_file:
                 spec_file.write(environment_spec.spec)
-            with open(os.path.join(path_to_spec, "poetry.lock"), "w", encoding="utf-8") as lock_file:
+            with open(
+                os.path.join(path_to_spec, "poetry.lock"), "w", encoding="utf-8"
+            ) as lock_file:
                 lock_file.write(environment_spec.spec_lock)
         else:
             spec_hash = hash_spec(environment_spec.spec.encode("UTF-8"))
